@@ -12,13 +12,21 @@ class Domain(BaseAPI):
 
         super(Domain, self).__init__(*args, **kwargs)
 
+    @classmethod
+    def get_object(cls, api_token, domain_name):
+        """
+            Class method that will return a Domain object by ID.
+        """
+        domain = cls(token=api_token, name=domain_name)
+        domain.load()
+        return domain
+
     def load(self):
         # URL https://api.digitalocean.com/v2/domains
         domains = self.get_data("domains/%s" % self.name)
-        domain = domains[u'domain']
-        self.zone_file = domain[u'zone_file']
-        self.ttl = domain[u'ttl']
-        self.name = domain[u'name']
+
+        for attr in domains.keys():
+            setattr(self,attr,droplet[attr])
 
     def destroy(self):
         """
